#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import flask
import io
from configuration import *
from gestion_erreurs import *
from gestion_donnees import *
from gestion_unites import *
from trace_courbe import *
import matplotlib.pyplot as plt

import base64

from matplotlib.backends.backend_agg import FigureCanvasAgg as FigureCanvas

app = flask.Flask(__name__)

@app.route('/',methods=['POST','GET'])
def index():
    liste_err = initialise_erreurs()    
    val_form = config_init()
    if flask.request.method=="POST":
        if 'fichier_donnees' in flask.request.files:
            ## charger les donneés dans le formulaire
            fichier = flask.request.files['fichier_donnees']
        
            val_form = fichier_texte_vers_configdonnees(fichier,liste_err)
        
    return flask.render_template("index.html",err=liste_err[1],valform=val_form)

@app.route('/apropos')
def apropos():
    
    return flask.render_template("apropos.html",err=[])
 

@app.route("/courbe/<ext>", methods=['POST'])
def courbe_image(ext):
    liste_err = initialise_erreurs()
    data = flask.request.form
    
    config = gere_configuration(data,liste_err)
    
    l_jours,l_poids = gere_donneespoids(data,config["naissance"],liste_err)
    fig = cree_figure(config,l_jours,l_poids,liste_err)
    
    output = io.BytesIO()
    FigureCanvas(fig).print_png(output)
    
    plt.close(fig)
    if ext == "b64":
        return flask.Response(base64.b64encode(output.getvalue()), mimetype='text/plain')
    elif ext == "png":
        return flask.Response(output.getvalue(), mimetype='image/png')
    else:
        return flask.render_template("erreur_fatale.html",erreur="Le type d'image demandé n'est pas reconnu")
    
    #return flask.Response(base64.b64encode(output.getvalue()), mimetype='text/plain')

@app.route("/export_donnees",methods=['POST'])
def export_donnees():
    # exporte les données au format texte
    liste_err = initialise_erreurs()
    data = flask.request.form
    
    config = gere_configuration(data,liste_err)
    l_jours,l_poids = gere_donneespoids(data,config["naissance"],liste_err)

    texte = configuration_vers_texte(config)
    texte += donnees_poids_vers_texte(l_jours,l_poids)    
    
    return flask.Response(texte,mimetype="text/plain")

if __name__ == "__main__":
    app.run(host='0.0.0.0',debug=True)